<?php
	/*
	Plugin Name: Smart QRCodes
	Plugin URI: http://project.kodesmart.com/smart-qrcodes
	Description: Auto generate barcodes for your orders in woocommerce
	Version: 0.1
	Author: KodeSmart
	Author URI: http://kodesmart.com
	License: 
	*/

	// create custom plugin settings menu
	add_action('admin_menu', 'smart_create_qrcodes_submenu');
	add_action( 'woocommerce_order_details_after_order_table', 'smart_add_order_barcode',10,1 );
	add_action( 'woocommerce_email_after_order_table', 'smart_add_order_barcode',10,2 );

	/**
	 * Add Checked In Status to order status list
	 */
	add_action( 'init', 'register_custom_post_status', 10 );
	function register_custom_post_status() {
		register_post_status( 'wc-checked-in', array(
			'label'                     => _x( 'Check In', 'Order status', 'woocommerce' ),
			'public'                    => true,
			'exclude_from_search'       => false,
			'show_in_admin_all_list'    => true,
			'show_in_admin_status_list' => true,
			'label_count'               => _n_noop( 'Checked In <span class="count">(%s)</span>', 'Checked In <span class="count">(%s)</span>', 'woocommerce' )
		) );
	 
	}
	 
	/**
	 * Add checked in status to order page drop down
	 */
	add_filter( 'wc_order_statuses', 'custom_wc_order_statuses', 10 );
	function custom_wc_order_statuses( $order_statuses ) {
		$order_statuses['wc-checked-in'] = _x( 'Checked In', 'Order status', 'woocommerce' );
		return $order_statuses;
	}

	/**
	 * Add the barcode after the order details - web form and email
	 */
	function smart_add_order_barcode($order) {
		$barcodetype = "qr";
		if ($barcodetype == "qr"){
			$checkinpath = plugins_url( 'process-qr.php', __FILE__ );
		?>
	        <div class="smart_order_barcode_div" style="float:right;padding-top:10px;padding-right:10px;width:111px;"><img style="width:95%;" class="smart_order_barcode" src="https://api-bwipjs.metafloor.com/?bcid=qrcode&text=<?php echo $checkinpath . '?orderid='.$order->id; ?>" /></div>
		<?php
		}
	}
	  
	/**
	 * Show the barcode entry form
	 */
	function acceptQR_func( $atts ) {
		//Check the current users role
		$hasAdminRights = 0;
		$adminOptions = '';
		$user = wp_get_current_user();
		$allowed_roles = array('administrator', 'shop_manager');
		if( array_intersect($allowed_roles, $user->roles ) ) {  
		   $hasAdminRights = 1;
		   $adminOptions = '<option value="complete" '.(isset($_POST['orderaction']) && $_POST['orderaction'] == "complete" ? "selected" : "").'>Complete Order</option>
						  <option value="checkin" '.(isset($_POST['orderaction']) && $_POST['orderaction'] == "checkin" ? "selected" : "").'>Check In</option>';
		} 
		
		//Build the form 
		$form = '<div class="acceptQRform" style="margin:10px 0px 20px 0px;">
					<form action="" method="post">
						<select name="orderaction">
						  <option value="lookup" '.(isset($_POST['orderaction']) && $_POST['orderaction'] == "lookup" ? "selected" : "").'>Look Up</option>
						  '.$adminOptions.'
						</select>
						<input type="text" name="upc" placeholder="Scan or enter barcode" autofocus required>
						<input type="submit" value="Submit">
					</form>
				</div>';
				
		//Check if the form is posting back and perform the action
		if (isset($_POST['orderaction']))
		{
			$orderid = intval(substr($_POST['upc'],1));  //strip the 9 off the front and convert to integer - that is order id
			$order = new WC_Order($orderid);
			
			//Check if the order is found - if it doesn't have items probably doesn't exist
			if ( count( $order->get_items() ) <= 0 )
			{
				$form.=smart_BarcodeMessageDiv("Order $orderid was not found.","red",1);
			}
			//Check if the user has security to view the order
			elseif ($hasAdminRights == 0 && $order->user_id != get_current_user_id())
			{
				$form.=smart_BarcodeMessageDiv("Access denied for order $orderid.  Make sure you are logged in and double check the barcode entered.","red",1);
			}
			else 
			{
				switch ($_POST['orderaction']) {
					case "lookup":
						do_action( 'woocommerce_view_order', $orderid );
						
						break;
					case "complete":
						if ($order->status == 'completed')
						{
							$form.=smart_BarcodeMessageDiv("Order $orderid is already completed.  No action taken.","purple",1);
						}
						else
						{
							$order->add_order_note( __('Order completed via the Order Barcode plugin', 'woocommerce') );	
							$order->update_status( 'completed' );
							$form.=smart_BarcodeMessageDiv("Order $orderid was completed successfully!","green",0);
						}
						break;
					case "checkin":
						if ($order->status == 'checked-in')
						{
							$form.=smart_BarcodeMessageDiv("Order $orderid is already checked in. No action taken.","purple",0);
						}
						else
						{
							$order->add_order_note( __('Order checked in via the Order Barcode plugin', 'woocommerce') );	
							$order->update_status( 'wc-checked-in' );
							$form.=smart_BarcodeMessageDiv("Order $orderid was checked in successfully!","green",0);
						}
						break;
				}
			}
		}
		return $form;
	}
	add_shortcode( 'acceptQRform', 'acceptQR_func' );
	
	function smart_BarcodeMessageDiv($message,$color,$isError)
	{
		if ($isError == 1)
		{
			$class = "smart_qrcodes_error";
		}
		else
		{
			$class = "smart_qrcodes_msg";	
		}
		
		return "<div class=\"$class\" style=\"color:$color\">$message</div>";
	}
	
	function smart_create_qrcodes_submenu() {
		//create the admin menu for smartQRcodes if not exists
		global $menu;
		$menuExist = false;
		foreach($menu as $item) {
			if(strtolower($item[0]) == strtolower('smart')) {
				$menuExist = true;
			}
		}
		if(!$menuExist)
			require_once(plugin_dir_path(__FILE__) . '/smart-entry.php');	
		
		//create new top-level menu
		add_submenu_page('smart-dashboard', 'Order Barcodes', 'Order Barcodes', 'manage_options', 'smart-qrcodes-settings', 'smart_qrcodes_settings_page' ); 
		
		//call register settings function
		add_action( 'admin_init', 'register_smart_qrcodes_settings' );
	}
	
	
	function register_smart_qrcodes_settings() {
		//register our settings
		register_setting( 'smart-qrcodes-settings-group', 'smart_qrcodes_barcodetype' );
		register_setting( 'smart-qrcodes-settings-group', 'smart_qrcodes_text' );
		register_setting( 'smart-qrcodes-settings-group', 'smart_qrcodes_autocheckin' );
	}

	function smart_qrcodes_settings_page() {		
		?>

		<div class="postbox-container" style="min-width:500px; max-width:800px; padding: 0 20px 0 0;">
		<h2>QRCode Settings</h2>
        <hr>
		<?php if( isset($_GET['settings-updated']) ) { ?>
			<div id="message" class="updated">
				<p><strong><?php _e('Settings saved.') ?></strong></p>
			</div>
		<?php } ?>
		<p>Add QRCodes for you woocommerce tickets. Please select barcode type then save changes to activate.</p>
		<form method="post" action="options.php">
			<?php settings_fields( 'smart-qrcodes-settings-group' ); ?>
			<?php do_settings_sections( 'smart-qrcodes-settings-group' ); ?>
			<table class="form-table">
            	<tr valign="top">
				<th scope="row">Barcode Type</th>
				<td><select name="smart_qrcodes_barcodetype">
                        <option value="none" <?php echo (get_option('smart_qrcodes_barcodetype') == 'none' ? 'selected' : '');?>>None</option>
						<option value="qr" <?php echo (get_option('smart_qrcodes_barcodetype') == 'qr' ? 'selected' : '');?>>QR Code</option>
					</select>
                </td>
                <tr valign="top">
                	<th scope="row">Preview</th>
                	<td>                 	
                    	<div class="smart_order_barcode_div" style="text-align:left;margin-bottom:5px;"><img class="smart_order_barcode" src="http://bwipjs-api.metafloor.com/?bcid=qrcode&text=<?php echo get_option('smart_qrcodes_barcodetype'); ?>/9000000111.png?IsTextDrawn=1&value=9000000111" /></div>    
					</td>
                </tr>
				</tr>
                
				<tr valign="top">
				<th scope="row">QR Auto Check-In</th>
				<td>
					<input type="checkbox" name="smart_qrcodes_autocheckin" value="1"<?php checked( 1 == get_option('smart_qrcodes_autocheckin') ); ?> /> Enable

				</td>
				</tr>
				
			</table>
            <?php submit_button(); ?>
          </form>
		</div>
		<div class="postbox-container" style="width:250px;">
			<div id="sidebar">
				<h3>Plugin developed and made available by KodeSmart Blog. Check us out for more of the best free Wordpress and Woocommerce plugins. </h3>
				<a href="https://kodesmart.com"><img src="<?php echo plugins_url('images/welcome-kodesmart.jpg', __FILE__) ?>" style="margin:20px 0px 0px 0px;"/></a>
			</div>
		</div>
	<?php }